=======
History
=======

0.3.7 (2018-XX-XX)
------------------

* Node labels in CircosPlot can now be rotated with the `rotate_labels`
  argument.

0.3.6 (2018-02-20)
------------------

* Implemented edge colours, thanks to @noragak.

0.3.5 (2018-01-20)
------------------

* Disabled health checks on certain tests.
* Added ability to configure plot size.
* Added docs on preparing a new release.
* Updated dependencies.

0.3.2 (2017-09-18)
------------------

* All plots except for HivePlot are implemented.
* Implemented auto-colorbar for plots that have continuous node colors.

0.1.0 (2016-07-15)
------------------

* First release on PyPI.
